# Created by Q-ays.
# whosqays@gmail.com

import os

SECRET_KEY = os.environ.get('SECRET_KEY') or 'hard to guess string'

err_num = {
    "OK": 0,
    "DATAERR": 1,
    "DSANF": 2,
    "PARM": 3,
    "PARGERR": 4,
    "NOadmin": 5,
    "NOAUTH": 6
}

err_msg = {
    "OK": "OK",
    "DATAERR": "数据库错误",
    "DSANF": "第三方服务错误",
    "PARM": "参数错误",
    "PARGERR": "数据错误",
    "NOadmin": "被管理者",
    "NOAUTH": "没有权限"
}

"""
    状态码
    
    Notice::
        大于0，顺利执行
        小于0，执行出错        
    
"""
state_code = {

    -1: 'GET_WAY_ERROR',
    -2: 'MS_ERROR',
    -3: 'DATABASE_ERROR',
    -4: 'NOT_AUTHORIZED',
    -5: 'DATA_FORMAT_ERROR',
    -6: 'CONNECTION_TIMEOUT',
    -7: 'UNKNOWN_ERROR',
    -8: 'THIRD_PARTY_ERROR',
    -9: 'PARAM_ERROR',

    1: 'SUCCESS'
}

state_desc = {
    'GET_WAY_ERROR': 'api 网关错误',
    'MS_ERROR': '微服务错误',
    'DATABASE_ERROR': '数据库错误',
    'NOT_AUTHORIZED': '未授权，拒绝访问',
    'DATA_FORMAT_ERROR': '数据格式错误',
    'CONNECTION_TIMEOUT': '连接超时',
    'UNKNOWN_ERROR': '未知错误',
    'THIRD_PARTY_ERROR': '第三方服务错误',
    'PARAM_ERROR': '参数错误',

    'SUCCESS': '成功'

}


def revert(code, data=None, desc=None):
    """
    公共返回方法

    :param code: 状态码
    :param data: 返回数据
    :param desc: 描述
    :return:
    """

    try:
        msg = state_code[code]

        if not desc:
            desc = state_desc[msg]
    except KeyError as e:
        return revert(-9, e)

    if data:
        return {'code': code, 'msg': msg, 'desc': desc, 'data': data}
    else:
        return {'code': code, 'msg': msg, 'desc': desc}



# Created by Q-ays.
# whosqays@gmail.com


"""
    Example::

        from wisdoms.config import c
        c.get('name')
"""

import yaml


class Config:
    """
    读取yml配置文件
    """

    def __init__(self):

        try:
            with open('../.env', 'r', encoding='utf-8') as f:
                env = f.read().strip()
        except FileNotFoundError as e:
            print('file path is ../../.env')
            with open('../../.env', 'r', encoding='utf-8') as f:
                env = f.read().strip()

        if env:
            try:
                with open('./config/' + env + '.yml') as f:
                    self.configuration = yaml.load(f)
            except FileNotFoundError as e:
                print('file path is ../config')
                with open('../config/' + env + '.yml') as f:
                    self.configuration = yaml.load(f)

    def get(self, key):
        if self.configuration:
            return self.configuration[key]
        else:
            return {'err_code': 'maybe environment variable is missed'}

    def to_dict(self):
        if self.configuration:
            return self.configuration


c = Config()



"""
    Example::

        from wisdoms.auth import permit

        host = {'AMQP_URI': "amqp://guest:guest@localhost"}

        auth = permit(host)

        class A:
            @auth
            def func():
                pass
"""

from nameko.standalone.rpc import ClusterRpcProxy
from functools import wraps


def permit(host):
    """ 调用微服务功能之前，进入基础微服务进行权限验证

    :param: host: micro service host
    """

    def wrapper(f):
        @wraps(f)
        def inner(*args, **kwargs):
            srv_name = args[0].name
            uid = args[1]['uid']
            f_name = f.__name__
            with ClusterRpcProxy(host) as rpc:
                res = rpc.db_service.isrole_app(srv_name, uid, f_name)
            if res['err_num'] == 0:
                return f(*args, **kwargs)
            return res

        return inner

    return wrapper



# Created by Q-ays.
# whosqays@gmail.com


import setuptools

with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name="wisdoms",
    version="0.0.6",
    author="tzxd group",
    author_email="whosqays@qq.com",
    description="those common functions of package for inner corporation",
    long_description=long_description,
    long_description_content_type="text/markdown",
    # url="https://github.com/pypa/sampleproject",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)